@@ -1,6 +1,5 @@
-from enum import Enum
-
-class FeaturesType(Enum):
+import enum
+class FeaturesType(enum.IntEnum):
     HISTORY=1
     HISTORY_ADVANCED=2
     STANDARD=3
