@@ -296,6 +296,11 @@ class RealTimeSignalEnsemblingParalleLauncher():
                                                                                list_pkl_file_name=self.min_calib_list_pkl_file_name)
             self.day_calib_signals_list = napoleon_connector.load_pickled_list(local_root_directory=self.local_root_directory,
                                                                                list_pkl_file_name=self.day_calib_list_pkl_file_name)
+        self.min_calib_signals_list = list(self.min_calib_signals_list )
+        self.min_calib_signals_list.sort()
+
+        self.day_calib_signals_list = list(self.day_calib_signals_list )
+        self.day_calib_signals_list.sort()
 
         self.minute_signal_mapping={}
         minute_max_lookback_window = 0
@@ -746,27 +751,18 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print('parallel computation done')
         print('results length')
         print(len(run_results))
-        new_data_sig = np.array(run_results)
-        if len(self.day_np.shape)>1:
-            new_data_sig = np.hstack((self.day_np[-1,:].reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
-        else:
-            new_data_sig = np.hstack((self.day_np.reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
-        print('new daily data signal')
-        print(new_data_sig)
-        if self.day_signal_np is None:
-            self.day_signal_np = new_data_sig
-        else:
-            self.day_signal_np = np.vstack((self.day_signal_np, new_data_sig))
-        if len(self.day_signal_np.shape)>1 and len(self.day_signal_np)>3:
-            print('last three daily signals')
-            print(self.day_signal_np[-3:])
+        raise Exception('plug trigger')
+
 
     def launchDaySequential(self):
         self.update_day_dataframe()
         print('launching sequential daily computation for alphas at '+str(self.last_day))
         run_results = []
+        trigger_results = []
         for meArg in self.day_calib_signals_list:
-            run_results.append(self.runDaySignal(meArg))
+            signal_value, trigger_value = self.runDaySignal(meArg)
+            run_results.append(signal_value)
+            trigger_results.append(trigger_value)
         print('results length')
         print(len(run_results))
         new_data_sig = np.array(run_results)
@@ -783,6 +779,16 @@ class RealTimeSignalEnsemblingParalleLauncher():
         if len(self.day_signal_np.shape)>1 and len(self.day_signal_np)>3:
             print('last three daily signals')
             print(self.day_signal_np[-3:])
+            print('forward filling the triggered daily signals ')
+            counter = 0
+            for meArg in self.day_calib_signals_list:
+                triggered = trigger_results[counter]
+                if triggered:
+                    signal_counter = len(self.generic_columns)+counter
+                    for row_idx in range(1, self.day_signal_np.shape[0]):
+                        if np.isnan(self.day_signal_np[row_idx, signal_counter]):
+                            self.day_signal_np[row_idx, signal_counter] = self.day_signal_np[row_idx-1, signal_counter]
+                counter = counter + 1
 
 
     def launchMinuteParallelPool(self, use_num_cpu):
@@ -790,32 +796,22 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print('launching parallel computation for alphas at '+str(self.last_minute))
         with Pool(processes=use_num_cpu) as pool:
             run_results = pool.starmap(self.runMinuteSignal, self.min_calib_signals_list)
-        print('parallel computation done')
-        print('results length')
-        print(len(run_results))
-        new_data_sig = np.array(run_results)
-        if len(self.minute_np.shape)>1:
-            new_data_sig = np.hstack((self.minute_np[-1,:].reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
-        else:
-            new_data_sig = np.hstack((self.minute_np.reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
+        raise Exception('pluggg trigger')
 
-        print(new_data_sig)
-        if self.minute_signal_np is None:
-            self.minute_signal_np = new_data_sig
-        else:
-            self.minute_signal_np = np.vstack((self.minute_signal_np, new_data_sig))
-        if len(self.minute_signal_np.shape)>1 and len(self.minute_signal_np)>3:
-            print('last three signals')
-            print(self.minute_signal_np[-3:])
 
     def launchMinuteSequential(self):
         self.update_minute_dataframe()
-        print('launching sequential computation for alphas at '+str(self.last_minute))
+        print('launching sequential minute computation for alphas at '+str(self.last_minute))
         run_results = []
+        trigger_results = []
         for meArg in self.min_calib_signals_list:
-            run_results.append(self.runMinuteSignal(meArg))
+            signal_value, trigger_value = self.runMinuteSignal(meArg)
+            run_results.append(signal_value)
+            trigger_results.append(trigger_value)
         print('results length')
         print(len(run_results))
+        print('triggered results')
+        print(trigger_results)
         new_data_sig = np.array(run_results)
         if len(self.minute_np.shape)>1:
             new_data_sig = np.hstack((self.minute_np[-1,:].reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
@@ -827,9 +823,20 @@ class RealTimeSignalEnsemblingParalleLauncher():
             self.minute_signal_np = new_data_sig
         else:
             self.minute_signal_np = np.vstack((self.minute_signal_np, new_data_sig))
+
         if len(self.minute_signal_np.shape)>1 and len(self.minute_signal_np)>3:
             print('last three signals')
             print(self.minute_signal_np[-3:])
+            print('forward filling the triggered minute signals ')
+            counter = 0
+            for meArg in self.min_calib_signals_list:
+                triggered = trigger_results[counter]
+                if triggered:
+                    signal_counter = len(self.generic_columns)+counter
+                    for row_idx in range(1, self.minute_signal_np.shape[0]):
+                        if np.isnan(self.minute_signal_np[row_idx, signal_counter]):
+                            self.minute_signal_np[row_idx, signal_counter] = self.minute_signal_np[row_idx-1, signal_counter]
+                counter = counter + 1
 
     def runMinuteSignal(self, me_signal):
         ## idiosyncratic run itself
@@ -840,16 +847,16 @@ class RealTimeSignalEnsemblingParalleLauncher():
         trigger = params['trigger']
         transaction_costs = params['transaction_costs']
         if normalization and not signal_generator.is_signal_continuum(signal_type):
-            return
+            return np.nan, trigger
         lookback_window = params['lookback_window']
         if lookback_window>self.minute_df.shape[0]:
-            return np.nan
+            return np.nan, trigger
         freqly = self.minute_df.iloc[-lookback_window:,:].copy()
         signal_generation_method_to_call = getattr(signal_generator, signal_type)
         last_generated_signal = signal_utility.compute_last_signal(freqly, lookback_window,
                                                                    lambda x: signal_generation_method_to_call(
                                                                        data=x, **params))
-        return last_generated_signal
+        return last_generated_signal, trigger
 
     def runDaySignal(self, me_signal):
         ## idiosyncratic run itself
@@ -860,10 +867,10 @@ class RealTimeSignalEnsemblingParalleLauncher():
         trigger = params['trigger']
         transaction_costs = params['transaction_costs']
         if normalization and not signal_generator.is_signal_continuum(signal_type):
-            return
+            return np.nan, trigger
         lookback_window = params['lookback_window']
         if lookback_window>self.day_df.shape[0]:
-            return np.nan
+            return np.nan, trigger
         freqly = self.day_df.iloc[-lookback_window:,:].copy()
         signal_generation_method_to_call = getattr(signal_generator, signal_type)
 
@@ -875,7 +882,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         #except Exception as e:
         #    print('Trouble computing signal ', e)
 
-        return last_generated_signal
+        return last_generated_signal, trigger
 
 
 
